pub enum ZipError {
Io(Error),
InvalidArchive(&'static str),
UnsupportedArchive(&'static str),
FileNotFound,
}Expand description
Error type for Zip
Variants
Io(Error)
An Error caused by I/O
InvalidArchive(&'static str)
This file is probably not a zip archive
UnsupportedArchive(&'static str)
This archive is not supported
FileNotFound
The requested file could not be found in the archive
Implementations
sourceimpl ZipError
impl ZipError
sourcepub const PASSWORD_REQUIRED: &'static str = "Password required to decrypt file"
pub const PASSWORD_REQUIRED: &'static str = "Password required to decrypt file"
The text used as an error when a password is required and not supplied
match archive.by_index(1) {
Err(ZipError::UnsupportedArchive(ZipError::PASSWORD_REQUIRED)) => eprintln!("a password is needed to unzip this file"),
_ => (),
}Trait Implementations
sourceimpl Error for ZipError
impl Error for ZipError
sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
The lower-level source of this error, if any. Read more
1.0.0 · sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()